darkhistory.electrons.ics.ics_spectrum.thomson_spec_series — DarkHistory documentation

# darkhistory.electrons.ics.ics_spectrum.thomson_spec_series

`darkhistory.electrons.ics.ics_spectrum.` `thomson_spec_series`(eleckineng, photeng, T, as_pairs=False)

  Thomson ICS spectrum of secondary photons by series method.

  Parameters: | eleckineng : ndarray Incoming electron kinetic energy. photeng : ndarray Outgoing photon energy. T : float CMB temperature. as_pairs : bool If true, treats eleckineng and photeng as a paired list: produces eleckineng.size == photeng.size values. Otherwise, gets the spectrum at each photeng for each eleckineng, returning an array of length eleckineng.size*photeng.size.
  Returns: | ndarray dN/(dt dE) of the outgoing photons (dt = 1 s), with abscissa photeng.

  Notes

  Insert note on the suitability of the method.

#### Previous topic

darkhistory.electrons.ics.ics_spectrum.ics_spec

#### Next topic

darkhistory.electrons.ics.ics_spectrum.thomson_spec_diff

### This Page

Show Source